==> qxcommon-1.0.06-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDGetUserInfoResp.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;


import java.util.List;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.db.QXDBManager;
import cn.com.startai.qxcommon.db.UserBean;
import cn.com.startai.qxcommon.utils.gson.QXJsonUtils;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDGetUserInfoResp extends HDGetUserInfoReq {


    /**
     * birthday : 1975-10-25
     * workStatus : 1
     * address : 上社
     * town : 天河区
     * city : 广州市
     * nation : 汉
     * sex : 1
     * type : 1
     * idNumber : 5451
     * entryTime : 2019-03-27
     * authSecret : 111111
     * cellPhoneNumber : 111
     * province : 广东省
     * name : 111
     * cmd : 16777218
     * email : @qq.com
     * remarks : 测试账号
     * updateName : 111
     * createName : 11
     * createTime :
     * updateTime :
     * postLists : [{"postId":"eefe5d7fd9fd35d6","postName":"餐吧"},{"postId":"45321bfc5eb72db4","postName":"特产"},{"postId":"116098d06bbdb2c0","postName":"大货"}]
     */
    private String birthday;
    private int workStatus;
    private String address;
    private String town;
    private String city;
    private String nation;
    private int sex;
    private int type;
    private String idNumber;
    private String entryTime;
    private String authSecret;
    private String cellPhoneNumber;
    private String province;
    private String name;
    private String email;
    private String remarks;
    private String updateName;
    private String createName;
    private String createTime;
    private String updateTime;
    private List<UserBean.PostInfoBean> postLists;

    public UserBean toUserBean() {
        UserBean userByUserid = QXDBManager.getInstance().getUserByUserid(getUserId());
        if (userByUserid != null) {
            userByUserid.setBirthday(birthday);
            userByUserid.setWorkStatus(workStatus);
            userByUserid.setAddress(address);
            userByUserid.setTown(town);
            userByUserid.setCity(city);
            userByUserid.setProvince(province);
            userByUserid.setNation(nation);
            userByUserid.setSex(sex);
            userByUserid.setIdNumber(idNumber);
            userByUserid.setType(type);
            userByUserid.setEntryTime(entryTime);
            userByUserid.setAuthSecret(authSecret);
            userByUserid.setCellPhoneNumber(cellPhoneNumber);
            userByUserid.setRealName(name);
            userByUserid.setEmail(name);
            userByUserid.setRemarks(name);
            userByUserid.setUpdateName(name);
            userByUserid.setUpdateTime(name);
            userByUserid.setCreateTime(name);
            userByUserid.setCreateName(name);
            userByUserid.setPostInfoList(postLists);
            userByUserid.setPostInfos(QXJsonUtils.toJson(postLists));
        }
        return userByUserid;
    }

    @Override
    public String toString() {
        return "HDGetUserInfoResp{" +
                "birthday='" + birthday + '\'' +
                ", workStatus=" + workStatus +
                ", address='" + address + '\'' +
                ", town='" + town + '\'' +
                ", city='" + city + '\'' +
                ", nation='" + nation + '\'' +
                ", sex=" + sex +
                ", type=" + type +
                ", idNumber='" + idNumber + '\'' +
                ", entryTime='" + entryTime + '\'' +
                ", authSecret='" + authSecret + '\'' +
                ", cellPhoneNumber='" + cellPhoneNumber + '\'' +
                ", province='" + province + '\'' +
                ", name='" + name + '\'' +
                ", email='" + email + '\'' +
                ", remarks='" + remarks + '\'' +
                ", updateName='" + updateName + '\'' +
                ", createName='" + createName + '\'' +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", postLists=" + postLists +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }


    @Override
    public long getCmd() {
        return HDCmd.HD_GET_TEAM_INFO;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public int getWorkStatus() {
        return workStatus;
    }

    public void setWorkStatus(int workStatus) {
        this.workStatus = workStatus;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getTown() {
        return town;
    }

    public void setTown(String town) {
        this.town = town;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }

    public int getSex() {
        return sex;
    }

    public void setSex(int sex) {
        this.sex = sex;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getIdNumber() {
        return idNumber;
    }

    public void setIdNumber(String idNumber) {
        this.idNumber = idNumber;
    }

    public String getEntryTime() {
        return entryTime;
    }

    public void setEntryTime(String entryTime) {
        this.entryTime = entryTime;
    }

    public String getAuthSecret() {
        return authSecret;
    }

    public void setAuthSecret(String authSecret) {
        this.authSecret = authSecret;
    }

    public String getCellPhoneNumber() {
        return cellPhoneNumber;
    }

    public void setCellPhoneNumber(String cellPhoneNumber) {
        this.cellPhoneNumber = cellPhoneNumber;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public List<UserBean.PostInfoBean> getPostLists() {
        return postLists;
    }

    public void setPostLists(List<UserBean.PostInfoBean> postLists) {
        this.postLists = postLists;
    }


}

==> qxcommon-1.0.24-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDGetUserInfoResp.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;


import java.util.List;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.db.QXDBManager;
import cn.com.startai.qxcommon.db.UserBean;
import cn.com.startai.qxcommon.utils.gson.QXJsonUtils;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDGetUserInfoResp extends HDGetUserInfoReq {


    /**
     * birthday : 1975-10-25
     * workStatus : 1
     * address : 上社
     * town : 天河区
     * city : 广州市
     * nation : 汉
     * sex : 1
     * type : 1
     * idNumber : 5451
     * entryTime : 2019-03-27
     * authSecret : 111111
     * cellPhoneNumber : 111
     * province : 广东省
     * name : 111
     * cmd : 16777218
     * email : @qq.com
     * remarks : 测试账号
     * updateName : 111
     * createName : 11
     * createTime :
     * updateTime :
     * postLists : [{"postId":"eefe5d7fd9fd35d6","postName":"餐吧"},{"postId":"45321bfc5eb72db4","postName":"特产"},{"postId":"116098d06bbdb2c0","postName":"大货"}]
     */
    private String birthday;
    private int workStatus;
    private String address;
    private String town;
    private String city;
    private String nation;
    private int sex;
    private int type;
    private String idNumber;
    private String entryTime;
    private String authSecret;
    private String cellPhoneNumber;
    private String province;
    private String name;
    private String email;
    private String remarks;
    private String updateName;
    private String createName;
    private String createTime;
    private String updateTime;
    private String jobNum;
    private String branchOfficeName;
    private String passengerSectionName;
    private String railwayBureauName;
    private String photo;
    private String graduateSchool;
    private String educationLevel;
    private String major;
    private int shelvesMode;
    private int cashTotalMoney;
    private int noCashTotalMoney;
    private int refundTotalMoney;
    private List<UserBean.PostInfoBean> postLists;


    @Override
    public String toString() {
        return "HDGetUserInfoResp{" +
                "birthday='" + birthday + '\'' +
                ", workStatus=" + workStatus +
                ", address='" + address + '\'' +
                ", town='" + town + '\'' +
                ", city='" + city + '\'' +
                ", nation='" + nation + '\'' +
                ", sex=" + sex +
                ", type=" + type +
                ", idNumber='" + idNumber + '\'' +
                ", entryTime='" + entryTime + '\'' +
                ", authSecret='" + authSecret + '\'' +
                ", cellPhoneNumber='" + cellPhoneNumber + '\'' +
                ", province='" + province + '\'' +
                ", name='" + name + '\'' +
                ", email='" + email + '\'' +
                ", remarks='" + remarks + '\'' +
                ", updateName='" + updateName + '\'' +
                ", createName='" + createName + '\'' +
                ", createTime='" + createTime + '\'' +
                ", updateTime='" + updateTime + '\'' +
                ", jobNum='" + jobNum + '\'' +
                ", branchOfficeName='" + branchOfficeName + '\'' +
                ", passengerSectionName='" + passengerSectionName + '\'' +
                ", railwayBureauName='" + railwayBureauName + '\'' +
                ", photo='" + photo + '\'' +
                ", graduateSchool='" + graduateSchool + '\'' +
                ", educationLevel='" + educationLevel + '\'' +
                ", major='" + major + '\'' +
                ", shelvesMode=" + shelvesMode +
                ", cashTotalMoney=" + cashTotalMoney +
                ", noCashTotalMoney=" + noCashTotalMoney +
                ", refundTotalMoney=" + refundTotalMoney +
                ", postLists=" + postLists +
                ", userId='" + userId + '\'' +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public int getNoCashTotalMoney() {
        return noCashTotalMoney;
    }

    public void setNoCashTotalMoney(int noCashTotalMoney) {
        this.noCashTotalMoney = noCashTotalMoney;
    }

    public int getRefundTotalMoney() {
        return refundTotalMoney;
    }

    public void setRefundTotalMoney(int refundTotalMoney) {
        this.refundTotalMoney = refundTotalMoney;
    }

    public int getCashTotalMoney() {
        return cashTotalMoney;
    }

    public void setCashTotalMoney(int cashTotalMoney) {
        this.cashTotalMoney = cashTotalMoney;
    }

    public int getShelvesMode() {
        return shelvesMode;
    }

    public void setShelvesMode(int shelvesMode) {
        this.shelvesMode = shelvesMode;
    }

    public UserBean toUserBean() {
        UserBean userByUserid = QXDBManager.getInstance().getUserByUserid(getUserId());
        if (userByUserid != null) {
            userByUserid.setBirthday(birthday);
            userByUserid.setWorkStatus(workStatus);
            userByUserid.setAddress(address);
            userByUserid.setTown(town);
            userByUserid.setCity(city);
            userByUserid.setProvince(province);
            userByUserid.setNation(nation);
            userByUserid.setSex(sex);
            userByUserid.setIdNumber(idNumber);
            userByUserid.setType(type);
            userByUserid.setEntryTime(entryTime);
            userByUserid.setAuthSecret(authSecret);
            userByUserid.setCellPhoneNumber(cellPhoneNumber);
            userByUserid.setRealName(name);
            userByUserid.setEmail(email);
            userByUserid.setRemarks(remarks);
            userByUserid.setUpdateName(updateName);
            userByUserid.setUpdateTime(updateTime);
            userByUserid.setCreateTime(createTime);
            userByUserid.setCreateName(createName);
            userByUserid.setPostInfoList(postLists);
            userByUserid.setPostInfos(QXJsonUtils.toJson(postLists));
            userByUserid.setJobNum(jobNum);
            userByUserid.setBranchOfficeName(branchOfficeName);
            userByUserid.setPassengerSectionName(passengerSectionName);
            userByUserid.setRailwayBureauName(railwayBureauName);
            userByUserid.setHeadPic(photo);
            userByUserid.setMajor(major);
            userByUserid.setGraduateSchool(graduateSchool);
            userByUserid.setEducationLevel(educationLevel);
            userByUserid.setShelvesMode(shelvesMode);
        }
        return userByUserid;
    }

    public String getGraduateSchool() {
        return graduateSchool;
    }

    public void setGraduateSchool(String graduateSchool) {
        this.graduateSchool = graduateSchool;
    }

    public String getEducationLevel() {
        return educationLevel;
    }

    public void setEducationLevel(String educationLevel) {
        this.educationLevel = educationLevel;
    }

    public String getMajor() {
        return major;
    }

    public void setMajor(String major) {
        this.major = major;
    }

    public String getPhoto() {
        return photo;
    }

    public void setPhoto(String photo) {
        this.photo = photo;
    }

    public String getPassengerSectionName() {
        return passengerSectionName;
    }

    public void setPassengerSectionName(String passengerSectionName) {
        this.passengerSectionName = passengerSectionName;
    }

    public String getRailwayBureauName() {
        return railwayBureauName;
    }

    public void setRailwayBureauName(String railwayBureauName) {
        this.railwayBureauName = railwayBureauName;
    }

    public String getBranchOfficeName() {
        return branchOfficeName;
    }

    public void setBranchOfficeName(String branchOfficeName) {
        this.branchOfficeName = branchOfficeName;
    }


    public String getJobNum() {
        return jobNum;
    }

    public void setJobNum(String jobNum) {
        this.jobNum = jobNum;
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_GET_TEAM_INFO;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public int getWorkStatus() {
        return workStatus;
    }

    public void setWorkStatus(int workStatus) {
        this.workStatus = workStatus;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getTown() {
        return town;
    }

    public void setTown(String town) {
        this.town = town;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getNation() {
        return nation;
    }

    public void setNation(String nation) {
        this.nation = nation;
    }

    public int getSex() {
        return sex;
    }

    public void setSex(int sex) {
        this.sex = sex;
    }

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getIdNumber() {
        return idNumber;
    }

    public void setIdNumber(String idNumber) {
        this.idNumber = idNumber;
    }

    public String getEntryTime() {
        return entryTime;
    }

    public void setEntryTime(String entryTime) {
        this.entryTime = entryTime;
    }

    public String getAuthSecret() {
        return authSecret;
    }

    public void setAuthSecret(String authSecret) {
        this.authSecret = authSecret;
    }

    public String getCellPhoneNumber() {
        return cellPhoneNumber;
    }

    public void setCellPhoneNumber(String cellPhoneNumber) {
        this.cellPhoneNumber = cellPhoneNumber;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }


    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public List<UserBean.PostInfoBean> getPostLists() {
        return postLists;
    }

    public void setPostLists(List<UserBean.PostInfoBean> postLists) {
        this.postLists = postLists;
    }


}
